import { createRouter, createWebHistory } from "vue-router";

const router = createRouter({
  history: createWebHistory(import.meta.env.BASE_URL),
  routes: [
    {
      path: "/",
      name: "home",
      component: () => import("../views/HomeView.vue"),
    },

    /**
     * General
     */
    {
      path: "/table_to_markdown_table",
      name: "table_to_markdown_table",
      component: () => import("../views/general/TableToMarkdownTable.vue"),
    },
    {
      path: "/table_to_mediawiki_table",
      name: "table_to_mediawiki_table",
      component: () => import("../views/general/TableToMediawikiTable.vue"),
    },
    {
      path: "/humans_txt",
      name: "humans_txt",
      component: () => import("../views/general/HumansTxt.vue"),
    },
    {
      path: "/percent_of_number",
      name: "%_of_number",
      component: () => import("../views/general/PercentOfNumber.vue"),
    },

    /**
     * String manipulation
     */
    {
      path: "/str_length",
      name: "str_length",
      component: () => import("../views/strings/Length.vue"),
    },
    {
      path: "/str_sort_lines",
      name: "str_sort_lines",
      component: () => import("../views/strings/SortLines.vue"),
    },
    {
      path: "/str_to_lower_upper",
      name: "str_to_lower_upper",
      component: () => import("../views/strings/ToLowerUppper.vue"),
    },
    {
      path: "/str_remove_duplicate_lines",
      name: "str_remove_duplicate_lines",
      component: () => import("../views/strings/RemoveDuplicateLines.vue"),
    },
    {
      path: "/str_pad",
      name: "str_pad",
      component: () => import("../views/strings/Pad.vue"),
    },
    {
      path: "/str_numeronym",
      name: "str_numeronym",
      component: () => import("../views/strings/Numeronym.vue"),
    },
    {
      path: "/str_to_nato_alphabet",
      name: "str_to_nato_alphabet",
      component: () => import("../views/strings/NATOAlphabet.vue"),
    },
    {
      path: "/url_encode_decode",
      name: "url_encode_decode",
      component: () => import("../views/strings/UrlEncodeDecode.vue"),
    },
    {
      path: "/url_query_viewer",
      name: "url_query_viewer",
      component: () => import("../views/strings/UrlQueryViewer.vue"),
    },
    {
      path: "/fix_ru_en_keyboard",
      name: "fix_ru_en_keyboard",
      component: () => import("../views/strings/FixRuEnKeyboard.vue"),
    },
    {
      path: "/iban_generator",
      name: "iban_generator",
      component: () => import("../views/generators/IbanGenerator.vue"),
    },

    /**
     * PHP
     */
    {
      path: "/str_to_php_array",
      name: "str_to_php_array",
      component: () => import("../views/php/StrToPHPArray.vue"),
    },
    {
      path: "/php_array_to_json",
      name: "php_array_to_json",
      component: () => import("../views/php/PHPArrayToJson.vue"),
    },
    {
      path: "/php_serialize",
      name: "php_serialize",
      component: () => import("../views/php/Serialize.vue"),
    },

    /**
     * JSON
     */
    {
      path: "/json_formatter",
      name: "json_formatter",
      component: () => import("../views/json/Formatter.vue"),
    },
    {
      path: "/json_minifier",
      name: "json_minifier",
      component: () => import("../views/json/Minifier.vue"),
    },

    /**
     * YAML
     */
    {
      path: "/yaml_formatter",
      name: "yaml_formatter",
      component: () => import("../views/yaml/Formatter.vue"),
    },

    /**
     * Golang
     */
    {
      path: "/go_json_to_struct",
      name: "go_json_to_struct",
      component: () => import("../views/go/JSONToStruct.vue"),
    },
    {
      path: "/sql_tables_to_struct",
      name: "sql_tables_to_struct",
      component: () => import("../views/go/SQLTablesToStruct.vue"),
    },

    /**
     * Docker
     */
    {
      path: "/docker_rename_volume",
      name: "docker_rename_volume",
      component: () => import("../views/docker/RenameVolume.vue"),
    },
    {
      path: "/docker_convert_run_compose",
      name: "docker_convert_run_compose",
      component: () => import("../views/docker/ConvertRunCompose.vue"),
    },

    /**
     * SQL manipulation
     */
    {
      path: "/sql_split_in",
      name: "sql_split_in",
      component: () => import("../views/sql/SplitInView.vue"),
    },
    {
      path: "/sql_formatter",
      name: "sql_formatter",
      component: () => import("../views/sql/Formatter.vue"),
    },

    /**
     * Generators
     */
    {
      path: "/dummy_image",
      name: "dummy_image",
      component: () => import("../views/generators/DummyImage.vue"),
    },
    {
      path: "/qr_code",
      name: "qr_code",
      component: () => import("../views/generators/QRCode.vue"),
    },

    /**
     * Unix
     */
    {
      path: "/unix_timestamp",
      name: "unix_timestamp",
      component: () => import("../views/unix/UnixTimestamp.vue"),
    },
    {
      path: "/file_base64_encode_decode",
      name: "file_base64_encode_decode",
      component: () => import("../views/unix/FileBase64EncodeDecode.vue"),
    },
    {
      path: "/sed_generator",
      name: "sed_generator",
      component: () => import("../views/unix/SedGenerator.vue"),
    },
    {
      path: "/htaccess_generator",
      name: "htaccess_generator",
      component: () => import("../views/unix/HtaccessGenerator.vue"),
    },
    {
      path: "/explain_crontab",
      name: "explain_crontab",
      component: () => import("../views/unix/ExplainCrontab.vue"),
    },

    /**
     * Other
     */
    {
      path: "/phpinfo",
      name: "phpinfo",
      component: () => import("../views/PHPInfo.vue"),
    },
  ],
});

export default router;
